# CodeMirror: Active Line Demo

<?xml version="1.0" encoding="UTF-8"?> <rss xmlns:atom="http://www.w3.org/2005/Atom" version="2.0" xmlns:georss="http://www.georss.org/georss" xmlns:twitter="http://api.twitter.com"> <channel> <title>Twitter / codemirror</title> <link>http://twitter.com/codemirror</link> <atom:link type="application/rss+xml" href="http://twitter.com/statuses/user_timeline/242283288.rss" rel="self"/> <description>Twitter updates from CodeMirror / codemirror.</description> <language>en-us</language> <ttl>40</ttl> <item> <title>codemirror: http://cloud-ide.com — they're springing up like mushrooms. This one uses CodeMirror as its editor.</title> <description>codemirror: http://cloud-ide.com — they're springing up like mushrooms. This one uses CodeMirror as its editor.</description> <pubDate>Thu, 17 Mar 2011 23:34:47 +0000</pubDate> <guid>http://twitter.com/codemirror/statuses/48527733722058752</guid> <link>http://twitter.com/codemirror/statuses/48527733722058752</link> <twitter:source>web</twitter:source> <twitter:place/> </item> <item> <title>codemirror: Posted a description of the CodeMirror 2 internals at http://codemirror.net/2/internals.html</title> <description>codemirror: Posted a description of the CodeMirror 2 internals at http://codemirror.net/2/internals.html</description> <pubDate>Wed, 02 Mar 2011 12:15:09 +0000</pubDate> <guid>http://twitter.com/codemirror/statuses/42920879788789760</guid> <link>http://twitter.com/codemirror/statuses/42920879788789760</link> <twitter:source>web</twitter:source> <twitter:place/> </item> </channel> </rss>

Styling the current cursor line.